@@ -5,11 +5,13 @@ package render
 
 import (
 	"fmt"
+	"log/slog"
+	"strings"
 
 	"github.com/derailed/k9s/internal/client"
 	"github.com/derailed/k9s/internal/model1"
+	"github.com/derailed/k9s/internal/slogs"
 	"github.com/derailed/tcell/v2"
-	"github.com/rs/zerolog/log"
 	"k8s.io/apimachinery/pkg/runtime"
 	"k8s.io/apimachinery/pkg/runtime/schema"
 )
@@ -78,14 +80,16 @@ func (Policy) Render(o interface{}, gvr string, r *model1.Row) error {
 // Helpers...
 
 func cleanseResource(r string) string {
-	if r == "" {
+	if r == "" || r[0] == '/' {
 		return r
 	}
-	if r[0] == '/' {
+	tt := strings.Split(r, "/")
+	switch len(tt) {
+	case 2, 3:
+		return strings.TrimPrefix(r, tt[0]+"/")
+	default:
 		return r
 	}
-	_, n := client.Namespaced(r)
-	return n
 }
 
 // PolicyRes represents a rbac policy rule.
@@ -158,7 +162,7 @@ func (pp Policies) Upsert(p PolicyRes) Policies {
 	}
 	p, err := pp[idx].Merge(p)
 	if err != nil {
-		log.Error().Err(err).Msg("policy upsert failed")
+		slog.Error("Policy upsert failed", slogs.Error, err)
 		return pp
 	}
 	pp[idx] = p
